@@ -21,6 +21,8 @@ _re_terminal_mode_response = re.compile(
     "^" + re.escape("\x1b[") + r"\?(?P<mode_id>\d+);(?P<setting_parameter>\d)\$y"
 )
 
+_re_cursor_position = re.compile(r"\x1b\[(?P<row>\d+);(?P<col>\d+)R")
+
 BRACKETED_PASTE_START: Final[str] = "\x1b[200~"
 """Sequence received when a bracketed paste event starts."""
 BRACKETED_PASTE_END: Final[str] = "\x1b[201~"
@@ -39,10 +41,12 @@ class XTermParser(Parser[events.Event]):
         self.last_x = 0
         self.last_y = 0
 
-        self._debug_log_file = open("keys.log", "wt") if debug else None
+        self._debug_log_file = open("keys.log", "at") if debug else None
 
         super().__init__()
 
+        self.debug_log("---")
+
     def debug_log(self, *args: Any) -> None:  # pragma: no cover
         if self._debug_log_file is not None:
             self._debug_log_file.write(" ".join(args) + "\n")
@@ -100,7 +104,7 @@ class XTermParser(Parser[events.Event]):
     the reissued sequence being emitted as key events.
     """
 
-    def parse(self, on_token: TokenCallback) -> Generator[Awaitable, str, None]:
+    def parse(self, _on_token: TokenCallback) -> Generator[Awaitable, str, None]:
         ESC = "\x1b"
         read1 = self.read1
         sequence_to_key_events = self._sequence_to_key_events
@@ -109,6 +113,11 @@ class XTermParser(Parser[events.Event]):
         bracketed_paste = False
         use_prior_escape = False
 
+        def on_token(token: events.Event) -> None:
+            """Hook to log events."""
+            self.debug_log(str(token))
+            _on_token(token)
+
         def on_key_token(event: events.Key) -> None:
             """Token callback wrapper for handling keys.
 
@@ -235,8 +244,7 @@ class XTermParser(Parser[events.Event]):
                         if key_events:
                             break
                         # Or a mouse event?
-                        mouse_match = _re_mouse_event.match(sequence)
-                        if mouse_match is not None:
+                        if (mouse_match := _re_mouse_event.match(sequence)) is not None:
                             mouse_code = mouse_match.group(0)
                             event = self.parse_mouse_code(mouse_code)
                             if event:
@@ -245,14 +253,28 @@ class XTermParser(Parser[events.Event]):
 
                         # Or a mode report?
                         # (i.e. the terminal saying it supports a mode we requested)
-                        mode_report_match = _re_terminal_mode_response.match(sequence)
-                        if mode_report_match is not None:
+                        if (
+                            mode_report_match := _re_terminal_mode_response.match(
+                                sequence
+                            )
+                        ) is not None:
                             if (
                                 mode_report_match["mode_id"] == "2026"
                                 and int(mode_report_match["setting_parameter"]) > 0
                             ):
                                 on_token(messages.TerminalSupportsSynchronizedOutput())
                             break
+
+                        # Or a cursor position query?
+                        if (
+                            cursor_position_match := _re_cursor_position.match(sequence)
+                        ) is not None:
+                            row, column = cursor_position_match.groups()
+                            on_token(
+                                events.CursorPosition(x=int(column) - 1, y=int(row) - 1)
+                            )
+                            break
+
             else:
                 if not bracketed_paste:
                     for event in sequence_to_key_events(character):
