@@ -215,6 +215,11 @@ class MessagePump(metaclass=_MessagePumpMeta):
         """The current size of the message queue."""
         return self._message_queue.qsize()
 
+    @property
+    def is_dom_root(self):
+        """Is this a root node (i.e. the App)?"""
+        return False
+
     @property
     def app(self) -> "App[object]":
         """
@@ -239,6 +244,16 @@ class MessagePump(metaclass=_MessagePumpMeta):
             active_app.set(node)
             return node
 
+    @property
+    def is_attached(self) -> bool:
+        """Is this node linked to the app through the DOM?"""
+        node: MessagePump | None = self
+
+        while (node := node._parent) is not None:
+            if node.is_dom_root:
+                return True
+        return False
+
     @property
     def is_parent_active(self) -> bool:
         """Is the parent active?"""
@@ -260,19 +275,6 @@ class MessagePump(metaclass=_MessagePumpMeta):
         """
         return self.app._logger
 
-    @property
-    def is_attached(self) -> bool:
-        """Is the node attached to the app via the DOM?"""
-        from .app import App
-
-        node = self
-
-        while not isinstance(node, App):
-            if node._parent is None:
-                return False
-            node = node._parent
-        return True
-
     def _attach(self, parent: MessagePump) -> None:
         """Set the parent, and therefore attach this node to the tree.
 
