@@ -231,6 +231,8 @@ class MarkdownHeader(MarkdownBlock):
     DEFAULT_CSS = """
     MarkdownHeader {
         color: $text;
+        margin: 2 0 1 0;
+       
     }
     """
 
@@ -241,13 +243,10 @@ class MarkdownH1(MarkdownHeader):
     DEFAULT_CSS = """
 
     MarkdownH1 {
-        background: $accent-darken-2;
-        border: wide $background;
-        content-align: center middle;
-
-        padding: 1;
+        content-align: center middle;             
         text-style: bold;
-        color: $text;
+        color: $success;
+        &:light {color: $primary;}
     }
     """
 
@@ -258,13 +257,10 @@ class MarkdownH2(MarkdownHeader):
     DEFAULT_CSS = """
 
     MarkdownH2 {
-        background: $panel;
-        border: wide $background;
-        text-align: center;
         text-style: underline;
-        color: $text;
-        padding: 1;
-        text-style: bold;
+        color: $success;
+         &:light {color: $primary;}
+      
     }
     """
 
@@ -274,10 +270,11 @@ class MarkdownH3(MarkdownHeader):
 
     DEFAULT_CSS = """
     MarkdownH3 {
-        background: $surface;
+       
         text-style: bold;
-        color: $text;
-        border-bottom: wide $foreground;
+        color: $success;
+        &:light {color: $primary;}
+        margin: 1 0;
         width: auto;
     }
     """
@@ -288,8 +285,9 @@ class MarkdownH4(MarkdownHeader):
 
     DEFAULT_CSS = """
     MarkdownH4 {
-        text-style: underline;
+        text-style: bold underline;
         margin: 1 0;
+        color: $text;
     }
     """
 
@@ -302,6 +300,7 @@ class MarkdownH5(MarkdownHeader):
         text-style: bold;
         color: $text;
         margin: 1 0;
+       
     }
     """
 
@@ -348,10 +347,13 @@ class MarkdownBlockQuote(MarkdownBlock):
     DEFAULT_CSS = """
     MarkdownBlockQuote {
         background: $boost;
-        border-left: outer $success;
+        border-left: outer $success-darken-2;
         margin: 1 0;
         padding: 0 1;
     }
+    MarkdownBlockQuote:light {
+        border-left: outer $primary;
+    }
     MarkdownBlockQuote > BlockQuote {
         margin-left: 2;
         margin-top: 1;
@@ -491,10 +493,8 @@ class MarkdownTable(MarkdownBlock):
 
     DEFAULT_CSS = """
     MarkdownTable {
-        width: 100%;
-        margin: 1 0;
-        background: $panel;
-        border: wide $background;
+        width: 100%;     
+        background: $panel;        
     }
     """
 
@@ -547,6 +547,9 @@ class MarkdownBullet(Widget):
         width: auto;
         color: $success;
         text-style: bold;
+        &:light {
+            color: $primary;
+        }
     }
     """
 
@@ -594,9 +597,11 @@ class MarkdownFence(MarkdownBlock):
         margin: 1 0;
         overflow: auto;
         width: 100%;
-        height: auto;
+        height: auto;       
         max-height: 20;
         color: rgb(210,210,210);
+
+        
     }
 
     MarkdownFence > * {
@@ -661,8 +666,9 @@ class Markdown(Widget):
     DEFAULT_CSS = """
     Markdown {
         height: auto;
-        margin: 0 4 1 4;
+        margin: 0 2 1 2;
         layout: vertical;
+        color: $text;
     }
     .em {
         text-style: italic;
